Loops and Iterations
::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   updating.rst
   while.rst
   infinite_loops.rst
   continue.rst
   definite_for.rst
   loops.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   mixedupcode.rst
   WriteCode.rst
   pogil.rst
